@@ -6,25 +6,14 @@ use warnings;
 use FindBin qw( $Bin );
 use Gearman::Driver;
 use Net::Telnet;
+use Gearman::Client;
+use Gearman::Server;
+use Danga::Socket;
 
 my ( $host, $port ) = ( '127.0.0.1', 4731 );
 
 $|++;
 
-BEGIN {
-    eval "require Gearman::XS";
-    unless ($@) {
-        eval "require Gearman::XS qw(:constants)";
-        eval "require Gearman::XS::Client";
-        eval "require Gearman::XS::Server";
-    }
-    else {
-        eval "require Gearman::Client";
-        eval "require Gearman::Server";
-        eval "require Danga::Socket";
-    }
-}
-
 sub new {
     return bless {}, shift;
 }
@@ -41,6 +30,9 @@ sub run_gearmand {
 
         exit(0);
     }
+
+    sleep(5);
+    warn sprintf "gearmand started (%d)\n", $self->{gearmand_pid};
 }
 
 sub run_gearman_driver {
@@ -57,39 +49,24 @@ sub run_gearman_driver {
     }
 
     sleep(5);
+    warn sprintf "gearman-driver started (%d)\n", $self->{gearman_driver_pid};
 }
 
 sub gearman_client {
     my ( $self, $h, $p ) = @_;
+
     $h ||= $host;
     $p ||= $port;
 
-    my $client;
-    if ( has_xs() ) {
-        $client = Gearman::XS::Client->new();
-        $client->add_server( $h, $p );
-    }
-    else {
-        no strict 'refs';
-        $client = Gearman::Client->new( exceptions => 1 );
-        $client->job_servers("${h}:${p}");
+    my $client = Gearman::Client->new( exceptions => 1 );
+    $client->job_servers("${h}:${p}");
 
-        # Fake Gearman::XS interface
-        *{"Gearman::Client::do"} = sub { my $result = shift->do_task(@_); return ( 0, $result ? $$result : 0 ); };
-        *{"Gearman::Client::do_background"} = sub { shift->dispatch_background(@_); };
-    }
     return $client;
 }
 
 sub gearman_server_run {
-    if ( has_xs() ) {
-        my $server = Gearman::XS::Server->new( $host, $port );
-        $server->run();
-    }
-    else {
-        my $server = Gearman::Server->new( port => $port );
-        Danga::Socket->EventLoop();
-    }
+    my $server = Gearman::Server->new( port => $port );
+    Danga::Socket->EventLoop();
 }
 
 sub gearman_driver {
@@ -112,12 +89,6 @@ sub telnet_client {
     return $telnet;
 }
 
-sub has_xs {
-    eval "require Gearman::XS";
-    return 1 unless $@;
-    return 0;
-}
-
 sub DESTROY {
     my ($self) = @_;
 
